%define ALD_Ver		2.0

%define       use_introspection 0
%define       use_vala 0

Name:         libsoup

License:      LGPL
Summary:      libsoup is an HTTP client/server library for GNOME
Version:      2.74.3
Release:      0

#https://download.gnome.org/sources/libsoup/

#Requires:         gnutls >= 2.10.2
Requires:         glib2 >= 2.58.0
Requires:         libpsl >= 0.20

Source: %{name}-%{version}.tar.xz

%define DestDir		/net
# -----------------------------------------------------
%define auto_local %{_sourcedir}/AUTO_LOCAL-1.sh
%define have_auto_local %(if test -x %{auto_local} ; then echo 1 ; else echo 0 ; fi)

%if %{_target_cpu} == %{_build_cpu}
%define _srcrpmdir	%{_topdir}/SRPMS/%{ALD_Ver}
%define _CROSS 0
%define MakeLocCross 0
%else
# rpm --target=armv7hl -ba xxxxx.spec
%define _srcrpmdir	%{_topdir}/SRPMS/tmp
%define _CROSS 1
%define MakeLocCross 1
%define _host %{_arch}-%{_os}%{_gnu}
%endif

#------------------ CROSS DIR --------------------

%define docdir		%{_defaultdocdir}/gtk2-doc/%{name}

%if %{have_auto_local}
%define __os_install_post %{nil}
%define CrossPath	%(%{auto_local} -GetCrossPath -build_cpu=%{_build_cpu} -target_cpu=%{_target_cpu})
%endif

# ------------------- description ------------------------------------
%description
libsoup is an HTTP client/server library for GNOME. It uses GObjects
and the glib main loop, to integrate well with GNOME applications.
#-------------------------------
%package devel
Summary:      Libraries for the C compiler
%description devel
These libraries are needed to compile C code.
#-------------------------------
%package introspection
Summary:      used by non-C language bindings
Requires:     %{name}
%description introspection
used by non-C language bindings
#-------------------------------
%package vala
Summary:      vala interface to a library
Requires:     %{name}
%description vala
vala interface to a library
#-------------------------------
%package locale
Summary:      locale
%description locale
Locale
#-------------------------------
%package doc
Summary:      doc html for %{name}
%description doc
doc html for %{name}
#-------------------------------
%package %{_target_cpu}
Summary:      %{name} Cross-%{_target_cpu}
%description %{_target_cpu}
%{name} Cross-%{_target_cpu}

# ------------------- setup ------------------------------------------
%Prep
%setup -q -n %{name}-%{version}

# ------------------- Build ------------------------------------------
%Build
%if %{_CROSS}
PATH="%{CrossPath}/bin:$PATH"
export GCC_NoHostPath=d
%endif
export PATH

%if %{_arch} == "i386"
OPTFLAGS="-Os -march=i586 -mpreferred-stack-boundary=2 -falign-functions=1 -falign-jumps=1 -falign-loops=1 -fomit-frame-pointer"
%endif
%if %{_arch} == "x86_64"
OPTFLAGS="-Os"
%endif
%if %{_arch} == "arm"
OPTFLAGS="%{optflags} -Os -munaligned-access"
%endif

OPTFLAGS="$OPTFLAGS -fno-asynchronous-unwind-tables"

CFLAGS="$OPTFLAGS -std=gnu99"
CXXFLAGS="$OPTFLAGS"
LDFLAGS="-Wl,--gc-sections"

export CFLAGS CXXFLAGS LDFLAGS

%define srcdir "`pwd`"

meson setup \
  --buildtype=plain \
  --prefix=%{_prefix} \
  --libdir=%{_libdir} \
  --libexecdir=%{_libexecdir} \
  --bindir=%{_bindir} \
  --sbindir=%{_sbindir} \
  --includedir=%{_includedir} \
  --datadir=%{_datadir} \
  --mandir=%{_mandir} \
  --infodir=%{_infodir} \
  --localedir=%{_datadir}/locale \
  --sysconfdir=%{_sysconfdir} \
  --localstatedir=%{_localstatedir} \
  --sharedstatedir=%{_sharedstatedir} \
  --wrap-mode=nodownload \
  -Dgtk_doc=true \
  -Dntlm=disabled \
  -Dbrotli=disabled \
  -Dintrospection=disabled \
  -Dvapi=disabled \
  -Dsysprof=disabled \
  %{srcdir}  _Build \
  &>FConfigure_log.txt

ninja -C _Build &>FMake_log.txt

# ------------------- Install ----------------------------------------
%Install

%if %{_CROSS}
export PATH="%{CrossPath}/bin:$PATH"
export GCC_NoHostPath=d
%endif

rm -rf $RPM_BUILD_ROOT
mkdir -p %{_srcrpmdir}
mkdir -p $RPM_BUILD_ROOT%{docdir}

DESTDIR=$RPM_BUILD_ROOT ninja -C _Build install \
	 &>Finstall_log.txt

cp AUTHORS README $RPM_BUILD_ROOT%{docdir}/
ln -s /usr/share/doc/lgpl-2.0.txt $RPM_BUILD_ROOT%{docdir}/COPYING

%if %{have_auto_local}
  %{auto_local} -build_cpu=%{_build_cpu} -target_cpu=%{_target_cpu} \
	-MakeLocCross=%{MakeLocCross} -DelLocCrossDir=%{_bindir}
%endif  # have_auto_local

# ------------------- Clean ------------------------------------------
%Clean

%if %{have_auto_local}
  %{auto_local} -build_cpu=%{_build_cpu} -target_cpu=%{_target_cpu} \
	-MakeLocCross=%{MakeLocCross} \
	-ALD_Ver=%{ALD_Ver} -RpmMovePath=%{DestDir} -tar_arg=bzip2
%endif  # have_auto_local

# ------------------- Files ------------------------------------------
%files
%{_libdir}/*.so.*
%{docdir}

%files devel
%{_includedir}
%{_libdir}/*.so
%{_libdir}/pkgconfig

%if %{use_introspection}
%files introspection
%{_libdir}/girepository-1.0
%{_datadir}/gir-1.0
%endif

%if %{use_vala}
%files vala
%{_datadir}/vala/vapi
%endif

%files locale
%{_datadir}/locale

%files doc
%{_datadir}/gtk-doc/html

# ------------------- Cross Files ------------------------------------
%if %{MakeLocCross} && %{have_auto_local}

%files %{_target_cpu}
%{cross_libdir}
%{cross_includedir}
%{cross_docdir}

%endif # MakeLocCross
